@@ -15,7 +15,7 @@ abbreviateTimeLabels <- function(t, ...)
     if (!inherits(t, "POSIXt"))
         return(t)                     # not a time, so just return the argument
     dots <- list(...)
-    if (!is.na(dots$format))
+    if ("format" %in% names(dots$format))
         return(format(t, dots$format)) # a format was specified, so just return the argument
     t <- format(t, "%Y-%m-%d %H:%M:%S")
     n <- length(t)
@@ -62,33 +62,22 @@ paletteCalculations <- function(paletteSeparation=1/8, paletteWidth=1/4, label,
     pc 
 }
 
-drawPalette <- function(zlim,
-                        zlab="",
-                        breaks,
-                        col,
-                        labels=NULL,
-                        at=NULL,
-                        mai=c(0, 1/8, 0, 3/8),
-                        top=0, bottom=0,
-                        drawContours=FALSE,
-                        debug=getOption("oceDebug"),
-                        ...)
+drawPalette <- function(zlim, zlab="", breaks, col,
+                        labels=NULL, at=NULL, mai, fullpage=FALSE,
+                        drawContours=FALSE, drawTriangles=FALSE,
+                        debug=getOption("oceDebug"), ...)
 {
-    if (top != 0) {
-        warning("drawPalette(): please use mai instead of top\n")
-        mai[3] <- top
-    }
-    if (bottom != 0) {
-        warning("drawPalette(): please use mai instead of bottom\n")
-        mai[1] <- bottom
-    }
     zlimGiven <- !missing(zlim)
+    if (zlimGiven)
+        zlim <- range(zlim, na.rm=TRUE)
     breaksGiven <- !missing(breaks)
     if (zlimGiven)
-        oceDebug(debug, "\bdrawPalette(zlim=c(", zlim[1], ",", zlim[2], "), zlab=", "\"", if (is.character(zlab)) zlab else
-            "(expression)", "\", ...) {\n", sep="")
+        oceDebug(debug, "\bdrawPalette(zlim=c(", zlim[1], ",",
+                 zlim[2], "), zlab=", "\"", as.character(zlab), "\",
+                 drawTriangles=", drawTriangles, "...) {\n", sep="")
     else
-        oceDebug(debug, "palette() with no arguments: set space to right of a graph\n")
+        oceDebug(debug, "\bdrawPalette() with no arguments: set space to right of a graph\n", sep="")
+    maiGiven <- !missing(mai)
     zIsTime <- zlimGiven && inherits(zlim[1], "POSIXt")
     if (zIsTime) {
         zlimOrig <- zlim
@@ -100,9 +89,9 @@ drawPalette <- function(zlim,
     oceDebug(debug, "original mai: omai=c(", paste(format(omai, digits=3), collapse=","), ")\n")
     omar <- par("mar")
     oceDebug(debug, "original mar: omar=c(", paste(format(omar, digits=3), collapse=","), ")\n")
-
+    if (!maiGiven)
+        mai <- c(0, 1/8, 0, 3/8 + if (nchar(zlab)) 1.5*par('cin')[2] else 0)
     pc <- paletteCalculations(mai=mai)
-
     contours <- NULL
     if (zlimGiven) {
         if (breaksGiven) {
@@ -130,15 +119,25 @@ drawPalette <- function(zlim,
         if (is.function(col))
             col <- col(n=length(breaks)-1)
     }
-##    theMai <- c(pc$omai[1]+mai[1],
-##                pc$main + pc$marLHS + pc$paletteSeparation + mai[2],
-##                pc$omai[3]+mai[3],
-##                pc$marRHS+mai[4])
-    theMai <- c(pc$omai[1]+mai[1],
-                pc$main + pc$maiLHS + mai[2],
-                pc$omai[3]+mai[3],
-                pc$maiRHS)
-    oceDebug(debug, "setting par(mai)=", format(theMai, digits=2), "\n")
+    oceDebug(debug, "fullpage=", fullpage, "\n")
+    oceDebug(debug, "maiGiven=", maiGiven, "\n")
+    if (fullpage) {
+        if (maiGiven) {
+            theMai <- mai
+        } else {
+            width <- par('fin')[1] # width
+            mai4 <- 3 * par('cin')[2]
+            mai2 <- 1/8 #width - paletteWidth - mai4
+            theMai <- c(omai[1], mai2, omai[3], mai4)
+            oceDebug(debug, "width=", width, ", mai2=", mai2, ", mai4=", mai4, "\n")
+        }
+    } else {
+        theMai <- c(pc$omai[1]+mai[1],
+                    pc$main + pc$maiLHS + mai[2],
+                    pc$omai[3]+mai[3],
+                    pc$maiRHS)
+    }
+    oceDebug(debug, "theMai=", theMai, "\n")
     if (zlimGiven) {
         par(mai=theMai)
         if (!breaksGiven) {
@@ -155,13 +154,42 @@ drawPalette <- function(zlim,
         if (drawContours)
             abline(h=contours)
         box()
+        drawTriangles <- rep(drawTriangles, length.out=2)
+        if (any(drawTriangles, na.rm=TRUE)) {
+            mai <- par('mai')
+            fin <- par('fin')
+            paletteWidth <- fin[1] - mai[2] - mai[4] # inch
+            paletteHeight <- fin[2] - mai[1] - mai[3] # inch
+            usr <- par('usr')
+            dx <- usr[2] - usr[1]      # user unit
+            dy <- usr[4] - usr[3]      # user unit
+            triangleHeight <- 1 / 3 * paletteWidth * dy / dx / paletteHeight
+            oceDebug(debug, "triangleHeight=", triangleHeight, "(user units)\n")
+            if (drawTriangles[2]) {
+                polygon(c(usr[1], 0.5*(usr[1]+usr[2]), usr[2]),
+                        usr[4] + c(0, triangleHeight, 0), col=col[length(col)], 
+                        border=col[length(col)], xpd=TRUE)
+                lines(c(usr[1], 0.5*(usr[1]+usr[2]), usr[2]),
+                      usr[4] + c(0, triangleHeight, 0),
+                      xpd=TRUE)
+            }
+            if (drawTriangles[1]) {
+                polygon(c(usr[1], 0.5*(usr[1]+usr[2]), usr[2]),
+                        usr[3] + c(0, -triangleHeight, 0), col=col[1], 
+                        border=col[1], xpd=TRUE)
+                lines(c(usr[1], 0.5*(usr[1]+usr[2]), usr[2]),
+                      usr[3] + c(0, -triangleHeight, 0),
+                      xpd=TRUE)
+            }
+        }
         if (zIsTime & is.null(at)) {
             at <- as.numeric(pretty(zlim))
         } else if (is.null(at)) {
             ## NB. in next line, the '10' matches a call to pretty() in imagep().
             at <- if (!is.null(contours) & is.null(at)) prettyLocal(contours, 10) else prettyLocal(palette, 10) # FIXME: wrong on contours
         }
-        if (is.null(labels)) labels <- if (zIsTime) abbreviateTimeLabels(numberAsPOSIXct(at), ...) else format(at)
+        if (is.null(labels))
+            labels <- if (zIsTime) abbreviateTimeLabels(numberAsPOSIXct(at), ...) else format(at)
         labels <- sub("^[ ]*", "", labels)
         labels <- sub("[ ]*$", "", labels)
         axis(side=4, at=at, labels=labels, mgp=c(2.5,0.7,0))
@@ -179,6 +207,8 @@ drawPalette <- function(zlim,
         par(new=TRUE, mai=theMai)
     else
         par(mai=theMai)
+    if (fullpage)
+        par(mai=omai)
     oceDebug(debug, "drawPalette at end mar=",par('mar'),"\n")
     oceDebug(debug, "\b\b} # drawPalette()\n")
     invisible()
@@ -186,19 +216,20 @@ drawPalette <- function(zlim,
 
 imagep <- function(x, y, z,
                    xlim, ylim, zlim,
+                   zclip=FALSE,
                    flipy=FALSE,
-                   xlab="", ylab="", zlab="",
+                   xlab="", ylab="", zlab="", zlabPosition=c("top", "side"),
                    breaks, col,
                    labels=NULL, at=NULL,
                    drawContours=FALSE,
+                   drawPalette=TRUE,
+                   drawTriangles=FALSE,
                    tformat,
                    drawTimeRange=getOption("oceDrawTimeRange"),
-                   drawPalette=TRUE,
                    filledContour=FALSE,
                    missingColor=NULL,
                    mgp=getOption("oceMgp"),
-                   mar=c(mgp[1]+if(nchar(xlab)>0) 1.5 else 1, mgp[1]+if(nchar(ylab)>0) 1.5 else 1, mgp[2]+1/2, 1/2),
-                   mai.palette=c(0, 1/8, 0, 3/8),
+                   mar, mai.palette,
                    xaxs = "i", yaxs = "i",
                    cex=par("cex"),
                    adorn,
@@ -207,9 +238,11 @@ imagep <- function(x, y, z,
                    debug=getOption("oceDebug"),
                    ...)
 {
-    oceDebug(debug, "\b\bimagep(..., cex=", cex, ", flipy=", flipy,
-             " xlab='", xlab, "'; ylab='", ylab, "'; zlab='", zlab,
-             " filledContour='", filledContour,
+    zlabPosition <- match.arg(zlabPosition)
+    oceDebug(debug, "\b\bimagep(..., cex=", cex, ", flipy=", flipy, ",", 
+             " xlab='", xlab, "'; ylab='", ylab, "'; zlab=\"", as.character(zlab), "\", ", 
+             " zlabPosition=\"", zlabPosition, "\", ",
+             " filledContour=", filledContour, ", ",
              " missingColor='", missingColor,
              ", ...) {\n", sep="")
     oceDebug(debug, "par(mar)=", paste(format(par('mar'), digits=3), collapse=" "), "\n")
@@ -295,10 +328,17 @@ imagep <- function(x, y, z,
         dy <- 0.5 * diff(y)
         y <- c(y[1L] - dy[1L], y[-length(y)] + dy, y[length(y)] + dy[length(y) - 1])
     }
-    attr(x,'tzone')<-tz
+    attr(x,'tzone') <- tz
     omai <- par("mai")
     omar <- par("mar")
     ocex <- par("cex")
+    if (missing(mar))
+        mar <- c(mgp[1]+if(nchar(xlab)>0) 1.5 else 1, mgp[1]+if(nchar(ylab)>0) 1.5 else 1, mgp[2]+1/2, 1/2)
+    if (missing(mai.palette)) {
+        mai.palette <- c(0, 1/8, 0, 3/8 + if (nchar(zlab) && zlabPosition=="side") 1.5*par('cin')[2] else 0)
+        oceDebug(debug, "set mai.palette=", mai.palette, "\n")
+    }
+
     par(mgp=mgp, mar=mar, cex=cex)
     breaksGiven <- !missing(breaks)
     if (!breaksGiven) {
@@ -335,13 +375,19 @@ imagep <- function(x, y, z,
     if (is.function(col))
         col <- col(n=length(breaks)-1)
 
+    #browser()
     if (drawPalette == "space") {
-        drawPalette()
+        drawPalette(zlab=if(zlabPosition=="side") zlab else "", debug=debug-1)
     } else if (drawPalette) {
         zlim <- if(missing(zlim)) range(z,na.rm=TRUE) else zlim
-        drawPalette(zlim=zlim, zlab="", breaks=breaks, col=col, 
+        drawTriangles <- rep(drawTriangles, length.out=2)
+        drawTriangles[1] <- drawTriangles[1] || any(z < zlim[1], na.rm=TRUE)
+        drawTriangles[2] <- drawTriangles[2] || any(z > zlim[2], na.rm=TRUE)
+        drawPalette(zlim=zlim, zlab=if(zlabPosition=="side") zlab else "",
+                    breaks=breaks, col=col, 
                     labels=labels, at=at,
                     drawContours=drawContours,
+                    drawTriangles=drawTriangles,
                     mai=mai.palette, debug=debug-1)
     }
 
@@ -353,6 +399,11 @@ imagep <- function(x, y, z,
         ## z[, seq.int(nc, 1L)] <- z[, seq.int(1L, nc)]
         ylim <- rev(ylim)
     }
+    if (zclip) {
+        oceDebug(debug, "using missingColour for out-of-range values")
+        z[z < zlim[1]] <- NA
+        z[z > zlim[2]] <- NA
+    }
     if (x.is.time) {
         if (filledContour) {
             if (!is.double(z))
@@ -407,7 +458,8 @@ imagep <- function(x, y, z,
         mtext(main, at=mean(range(x), na.rm=TRUE), side=3, line=1/8, cex=par("cex"))
     if (drawContours)
         contour(x=x, y=y, z=z, levels=breaks, drawlabels=FALSE, add=TRUE, col="black")
-    mtext(zlab, side=3, cex=par("cex"), adj=1, line=1/8)
+    if (zlabPosition == "top")
+        mtext(zlab, side=3, cex=par("cex"), adj=1, line=1/8)
     if (!missing(adorn)) {
         t <- try(eval.parent(adorn), silent=!TRUE)
         if (class(t) == "try-error")
